#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 17:54 Freitag, 17. März 2023 linux-runtime.py Volker Lange-Janson

import subprocess
import sys
import re
import time

# Nachfolgendes wird für die Kommunikation mit Asterisk benötigt:
####################################################################
# Read the incoming AGI environment variables
env = {}
tests = 0;

while 1:
   line = sys.stdin.readline().strip()

   if line == '':
      break
   key,data = line.split(':')
   if key[:4] != 'agi_':
      #skip input that doesn't begin with agi_
      sys.stderr.write("Did not work!\n");
      sys.stderr.flush()
      continue
   key = key.strip()
   data = data.strip()
   if key != '':
      env[key] = data
    
sys.stderr.write("AGI Environment Dump:\n");
sys.stderr.flush()
for key in env.keys():
   sys.stderr.write(" -- %s = %s\n" % (key, env[key]))
   sys.stderr.flush()
   
def checkresult (params):
   params = params.rstrip()
   if re.search('^200',params):
      result = re.search('result=(\d+)',params)
      if (not result):
         sys.stderr.write("FAIL ('%s')\n" % params)
         sys.stderr.flush()
         return -1
      else:
         result = result.group(1)
         #debug("Result:%s Params:%s" % (result, params))
         sys.stderr.write("PASS (%s)\n" % result)
         sys.stderr.flush()
         return int(result)
   else:
      error_code = re.search('result=(-?\d+)',params)
      if error_code:
         error_code = int(error_code.group(1))
         sys.stderr.write("FAIL (unexpected result '%s', error code %d)\n" % (params, error_code))
         sys.stderr.flush()
         return error_code
      else:
         sys.stderr.write("FAIL (unexpected result '%s')\n" % params)
         sys.stderr.flush()
         return -2

      
def saynumber (params):
   sys.stderr.write("SAY NUMBER %s \"\"\n" % params)
   sys.stderr.flush()
   sys.stdout.write("SAY NUMBER %s \"\"\n" % params)
   sys.stdout.flush()
   result = sys.stdin.readline().strip()
   return checkresult(result)
  
   
def sayit (params):
   sys.stderr.write("STREAM FILE %s \"\"\n" % str(params))
   sys.stderr.flush()
   sys.stdout.write("STREAM FILE %s \"\"\n" % str(params))
   sys.stdout.flush()
   result = sys.stdin.readline().strip()
   checkresult(result)

##################################################################
# Hier fängt das eigentliche Programm an

time_duration = 1
time.sleep(time_duration) 

sayit("/usr/share/asterisk/sounds/en_US_f_Allison/hello")
sys.stdout.flush()
time_duration = 1
time.sleep(time_duration)

# Laufzeit von Linux in Sekunden abrufen
output3 = subprocess.check_output('cat /proc/uptime', shell=True)
uptime_seconds = float(output3.split()[0])

# Laufzeit in Tagen umwandeln und runden
uptime_days = int(uptime_seconds / (60 * 60 * 24))

#######################################################################
#######################################################################

sayit("/usr/share/asterisk/sounds/eigene/statusmeldungen/uptime_days")
sys.stdout.flush()
time_duration = 1
time.sleep(time_duration)

saynumber(uptime_days);
sys.stdout.flush()

time_duration = 1
time.sleep(time_duration) 

#######################################################################
#######################################################################

sayit("/usr/share/asterisk/sounds/en_US_f_Allison/goodbye")
sys.stdout.flush()
time_duration = 1
time.sleep(time_duration)

#######################################################################

# Beispiel, wie das Skript in der extensions.conf aufgerufen wird
# durch die Wahl der 350
#
# exten => 350,1,Noop(Linux-Laufzeit: "${CALLERID(name)}" <${CALLERID(num)}>) 
#  same => n,Answer()    
#  same => n,AGI(linux-runtime.py)
#  same => n,Hangup()

# Sprachansagen:
# Laufzeit dieses Asterisk-Servers in Tagen:

